@@ -21,15 +21,18 @@ from moofei._valid import VALID
 from moofei._find import __find__, _parse_params, _py, isascii
 try:
     from util import get_free_mem, split_kv, execfile
+    from _cat import _cat
 except:
     from moofei.util import get_free_mem, split_kv, execfile
+    from moofei._cat import _cat
 
 from flask import Flask, request, send_from_directory
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 intervalDict={}
 prosDict = {}
 
-def static_file(path="", is_static=True, as_attachment=True): 
+def static_file(path="", is_static=True, is_zip=False, as_attachment=True): 
     if not path: path = 'find.html'
     if is_static:
         fpath = os.path.join(os.path.dirname(__file__),  'static', path)
@@ -43,11 +46,36 @@ def static_file(path="", is_static=True, as_attachment=True):
             dirpath,filename = './', fpath 
         #print(path, os.path.isfile(path),as_attachment)
         # as_attachment=True 一定要写，不然会变成打开，而不是下载
-        if not as_attachment and os.path.isfile(path):
+        if os.path.isfile(path):
             from flask import Response
-            return Response(open(path,'rb').read(), mimetype='text/txt')
-        return send_from_directory(dirpath, filename, as_attachment=as_attachment)  
-    
+            if not as_attachment :
+                return Response(open(path,'rb').read(), mimetype='text/txt')
+            elif is_zip:
+                backupdir = './.backup'
+                if not os.path.isdir(backupdir): os.mkdir(backupdir)
+                backupname = os.path.join(backupdir, 'temp.zip')
+                zip = zipfile.ZipFile(backupname, 'w', zipfile.ZIP_DEFLATED)
+                zip.write(path)
+                zip.close()
+                return Response(open(backupname,'rb').read(), mimetype='application/zip')
+            
+        return send_from_directory(dirpath, filename, as_attachment=as_attachment)
+
+@valid.func(['path:str', 'page:int', 'bsize:int', 'words:','not_word:', 'pre_word:', 'fpath:', 'fname:', 'file:', 'curpage:int','encoding:' ])
+def pageView(path, page, bsize, words='', not_word="", pre_word="", fpath="", fname="", file="", curpage=0, encoding=None):
+    path = path or fpath or fname or file
+    if path:
+        if curpage: page=curpage-1
+        elif not page: page=0
+        data = _cat(path, page=page, bsize=bsize, words=words, not_word=not_word, pre_word=pre_word, encoding=encoding) 
+        if data:
+            txts, inlines = data
+            rs = inlines[2]
+            rs['curpage'] = rs['page']+1
+            rs['path'] = path
+            rs['txt'] = '\n'.join(txts)
+            return rs
+            
 @valid.func(['interval:str'])
 def infoPros(interval):
     if interval and interval in intervalDict:
@@ -68,18 +96,24 @@ def stopPros(interval):
     return {'data':"OK"}     
                
 @valid.func(['interval:str', 'name:str','words:trim;str','fcase:int','ftype:int','wcase:int', 'plugin_box:strs','plugin_fix:strs','show_only_file:int','basedir:str','isdeep:int', 'fsize:trim', 'istry:int','more_break:int','mass_words:trim;str' ])
-def finds(interval, name='.', words="", fcase=1, ftype=None, wcase=0, plugin_box=None, plugin_fix=None, show_only_file=0, basedir="", isdeep=None, fsize=None, istry=0, more_break=1, mass_words="", **awgs):   
+def finds(interval, name='.', words="", fcase=1, ftype=None, wcase=0, plugin_box='', plugin_fix='', show_only_file=0, basedir="", isdeep=None, fsize=None, istry=0, more_break=1, mass_words="", **awgs):   
     if '.doc(x)' in plugin_fix: plugin_fix+=['.doc','.docx']
     if '.xls(x)' in plugin_fix: plugin_fix+=['.xls','.xlsx']
     if '.tar' in plugin_box: plugin_box+=['.tar.gz', '.tar.bz2', '.tar.xz']
     if not words: awgs.pop('rewords',None)  
-    now = time.time()    
+    now = time.time() 
+    
+    if not ftype and (not name or name=='.') and (words or awgs.get('rewords')):
+        ftype = 0
+    else:
+        ftype=(name in ('.','') and 2) or ftype or None
+        
     dawgs = dict(
                     basedir = basedir or "./",
                     fsize = fsize,
                     isdeep = isdeep,
                     words = re.compile(words) if words and wcase==2 else words,
-                    fcase = fcase, ftype=(name in ('.','') and 2) or ftype or None,
+                    fcase = fcase, ftype=ftype,
                     wcase = wcase,
                     show_only_file = show_only_file,
                     is_read_fcall = 1 if words else 0,
@@ -166,7 +200,9 @@ def finds(interval, name='.', words="", fcase=1, ftype=None, wcase=0, plugin_box
     if not intervalDict[interval]['finish'] and prosDict[interval].is_end:
         intervalDict[interval]['finish'] = 1
         intervalDict[interval]['result'].append('')
-        
+        iserror=prosDict[interval].is_error
+        if iserror:
+            intervalDict[interval]['result'].append(str(iserror))
         intervalDict[interval]['result'].append(":::::::::::::::::::: func error ::::::::::::::::::::::::::::::::::::::::::::::::::::::")
     return {'data':intervalDict[interval], 'pros_num':len(prosDict)}
 
@@ -229,7 +265,10 @@ def find_call(interval, name, dawgs, data):
         
     def fcall(fpath, *lst,**dct):
         frombox = dct.get('frombox')
-        if frombox: fpath = u'{0} -> {1}'.format(fpath, frombox)
+        try:
+            if frombox: fpath = u'{0} -> {1}'.format(fpath, frombox)
+        except UnicodeDecodeError:
+            if frombox: fpath = u'{0} -> {1}'.format(fpath.decode('gbk'), frombox)
         #fpath = VALID.isStr(fpath)[1]
         data['result'].append(fpath)
         data['filecount'] += 1
