@@ -10,7 +10,7 @@ Mufei _ __ ___   ___   ___  / _| ___(_)
 
 __all__ = ['_Image', ]
 
-import sys,os,json,re,time,math
+import sys,os,json,re,time,math,struct  
 import PIL
 from PIL import Image, ImageFile, ImageDraw, ImageFont, ImageChops, ImageEnhance, ImageSequence
 ImageFile.LOAD_TRUNCATED_IMAGES = True
@@ -130,8 +130,36 @@ class _Image:
         if is_open: f.close()    
         return bValid
 
+    @classmethod    
+    def file2png(cls, source, target):  
+        Bits = 3  
+        data = open(source, "rb").read()  
+        fileSize = len(data)  
+        data += b"\0\0\0"  
         
-
+        # Ratio 4:3  
+        width = int(math.sqrt(float(fileSize) / Bits * 4 / 3)) + 1  
+        height = int((fileSize/Bits) / width) + 1  
+        if width * height * Bits < fileSize: raise Exception("File Too Large")  
+        if width == 0 or height == 0: raise Exception("File Too Small.")  
+      
+        im = Image.new("RGB", (width, height)) 
+        if py[0]==2:    
+            pngData = tuple(tuple(map(ord, [y for y in data[x: x+Bits]])) for x in range(0, fileSize, Bits))  
+        else:
+            pngData = tuple(tuple([y for y in data[x: x+Bits]]) for x in range(0, fileSize, Bits))  
+        im.putdata(pngData)  
+        im.save(target, "PNG", transparency=struct.unpack("B"*Bits, struct.pack("I", fileSize)[:Bits]), compression = 9)    
+        im.close()
+        
+    @classmethod  
+    def png2file(cls, source, target): 
+        Bits = 3
+        im = Image.open(source)     
+        fileSize = struct.unpack("I",struct.pack("B"*Bits, *im.info["transparency"]) + b"\0"*(4-Bits))[0]
+        data = im.tobytes()[:fileSize] 
+        open(target, "wb").write(data)  
+        im.close() 
     
 def main(folder='./temp'):
     for f in os.listdir(folder):
