@@ -12,6 +12,7 @@ __all__ = ['_Pdf', ]
 
 import sys,os,json,re,time,math
 import tempfile
+import traceback
 from reportlab.lib.units import cm
 from reportlab.pdfgen import canvas 
 #py2.6: pip2 install reportlab --no-dependencies
@@ -174,7 +175,7 @@ class _Pdf:
                 a=10*(i-1)
                 b=5*(j-2)
                 c.drawString(a*cm, b*cm, s)
-                c.setFillAlpha(alpha)
+            c.setFillAlpha(alpha)
         # 关闭并保存pdf文件
         c.showPage()
         c.save()
@@ -246,7 +247,10 @@ class _Pdf:
                 for page_num  in range(pdf_reader.numPages):
                     #page = add_watermark(pdf_mark, pdf_reader.getPage(page_num))
                     page = pdf_reader.getPage(page_num)
-                    page.mergePage(pdf_mark_page)
+                    try:
+                        page.mergePage(pdf_mark_page)
+                    except:
+                        traceback.print_exc()
                     page.compressContentStreams()  # 压缩内容
                     #将合并后的即添加了水印的page对象添加到pdfWriter
                     pdf_writer.addPage(page)
