@@ -11,6 +11,7 @@ Mufei _ __ ___   ___   ___  / _| ___(_)
 __all__ = ['Tree', ]
 
 import sys, os
+import traceback
 from string import Template as string_Template
 py = list(sys.version_info)
 import copy
@@ -58,6 +59,8 @@ def Dsort(d):
         return d
             
     
+class unStr(str):pass
+class unList(list):pass 
     
 class Tree:
     __tree = False
@@ -123,7 +126,11 @@ class Tree:
             else:
                 if pid in FL: return FL
             if valueCode:
-                FL[pid] = tree[pid].get(valueCode,'')
+                if pid in tree:
+                    FL[pid] = tree[pid].get(valueCode,'')
+                else:
+                    print(pid, '(pid) Not In Tree!')
+                    return FL    
             else:
                 FL[pid] = tree[pid]
                 FL[pid].pop(name, None)
@@ -246,7 +253,7 @@ class Tree:
         return __tree 
     
     @classmethod
-    def to_dot(cls, List, id_key='id', pid_key='pid', val_key='name', sort_key='', deep=0, pid=0, dot='- ',reverse=False, tpl=None, Ls=None):
+    def to_dot(cls, List, id_key='id', pid_key='pid', val_key='name', sort_key='', deep=0, pid=0, dot='- ',reverse=False, find=None, tpl=None, Ls=None):
         '''
         >>> List =[{'id':1,'pid':0, 'name':1, 'nid':1},
         ...   {'id':2,'pid':0, 'name':1, 'nid':2},
@@ -267,10 +274,15 @@ class Tree:
                 if tpl is True:
                     s = '<option value="%s">%s%s</option>'%(d[id_key],dot*deep, d[val_key])
                 else:
-                    s = string_Template(tpl).substitute(dots=dot*deep, **d)                        
-                s += cls.to_dot(List, id_key, pid_key, val_key, sort_key, deep+1, d[id_key], dot, reverse, tpl=tpl)
-                Ls.append(s)
+                    s = string_Template(tpl).substitute(dots=dot*deep, **d)
+                fS = cls.to_dot(List, id_key, pid_key, val_key, sort_key, deep+1, d[id_key], dot, reverse, find, tpl=tpl) 
+                if find and isinstance(fS, unStr) and not fS and not find(d): 
+                    continue
+                else:
+                    s +=  fS
+                    Ls.append(s)
             rs = ''.join(Ls)
+            if find and not rs: rs = unStr()
         else:
             for d in L:
                 if isinstance(d,dict):
@@ -278,9 +290,14 @@ class Tree:
                 elif isinstance(d,tuple):
                     d = list(d)
                 if dot: d[val_key] = "%s%s"%(dot*deep,d[val_key])
-                Ls.append(d)
-                Ls += cls.to_dot(List, id_key, pid_key, val_key, sort_key, deep+1, d[id_key], dot, reverse)    
-            rs = Ls    
+                fL = cls.to_dot(List, id_key, pid_key, val_key, sort_key, deep+1, d[id_key], dot, reverse, find)
+                if find and isinstance(fL, unList) and not fL and not find(d):
+                    continue    
+                else:
+                    Ls.append(d)
+                    Ls += fL    
+            rs = Ls
+            if find and not rs: rs = unList()
         return rs
     
         
