@@ -4,9 +4,9 @@ if '--webbrowser' in sys.argv:
     #python find 127.0.0.1:5000 --webbrowser
     sys.argv.remove('--webbrowser')
     try:
-        from ..app import app
+        from ..view import app
     except ImportError:
-        from moofei.app import app
+        from moofei.view import app
     
     import argparse
     parser = argparse.ArgumentParser() 
