@@ -23,6 +23,7 @@ try:
 except ImportError:
     warnings.warn('Please Import pdfminer.six TO pip')
     pdfminer = None
+    PDFPage  = None
     
 try:
     import PyPDF2
@@ -369,19 +370,29 @@ class Plugin_Fix_Pdf(cPlugin_Fix):
 
         
     def all_texts(self):
-        Ls = []
-        for page in PDFPage.get_pages(self.fp  or open(self.fpath,'rb'),  caching=True,check_extractable=True):
-            resource_manager = PDFResourceManager()
-            fake_file_handle = _StringIO() if _py[0] == 2 else StringIO()
-            converter = TextConverter(resource_manager, fake_file_handle)
-            page_interpreter = PDFPageInterpreter(resource_manager, converter)
-            page_interpreter.process_page(page)
-            text = fake_file_handle.getvalue()
-            Ls.append(text)     
-            converter.close()
-            fake_file_handle.close()
-                
-        text = '\n'.join(Ls)
+        if pdfminer:
+            Ls = []        
+            for page in PDFPage.get_pages(self.fp  or open(self.fpath,'rb'),  caching=True,check_extractable=True):
+                resource_manager = PDFResourceManager()
+                fake_file_handle = _StringIO() if _py[0] == 2 else StringIO()
+                converter = TextConverter(resource_manager, fake_file_handle)
+                page_interpreter = PDFPageInterpreter(resource_manager, converter)
+                page_interpreter.process_page(page)
+                text = fake_file_handle.getvalue()
+                Ls.append(text)     
+                converter.close()
+                fake_file_handle.close()    
+            text = '\n'.join(Ls)
+        elif PyPDF2:
+            text = self.pypdf2text()
+        else:    
+            try:
+                import fitz
+                text = fitz_pdf2png(self, out_dir=None, to_txt=False)
+            except:
+                warnings.warn('Please Import fitz TO pip')
+                text = ""
+        #print(text)
         return text
         
         
