@@ -14,15 +14,16 @@ import re
 #import sys; sys.path.append('..') #
 try:
     from .. import _valid
-    from .._valid import  ValidDict, ValidMethod, getFuncDefaults, ValidResultParse
+    from .._valid import  ValidDict, ValidMethod,  ValidResultParse, unVal
 except (ImportError,ValueError):
     from moofei import _valid
-    from moofei._valid import  ValidDict, ValidMethod, getFuncDefaults, ValidResultParse
+    from moofei._valid import  ValidDict, ValidMethod,  ValidResultParse, unVal
 import time
 import json
 import traceback
 try:
     from inspect import signature
+    #list(inspect.signature(s).parameters)
 except:
     signature = None
 
@@ -155,7 +156,7 @@ class valid:
 
     
     @staticmethod
-    def func(validArgs, permit='', rate=None, block=False):
+    def func(validArgs=None, permit='', rate=None, block=False):
         '''valid.func
         >>> @valid.func(['a:int', 'b:true', 'c:ip', r'f:^\d+$'])
         ... def A(a,b,c,d=3,e=5, f='', **m): pass
@@ -191,14 +192,13 @@ class valid:
         ...     return JsonResponse(valid.request(index_func, request))
         '''
         t0 = time.time()
+        
         _fc = cls.__valid_pre_check
         
         attrs =  getattr(fn, "validArgs", None) or [] #attrs=fn.validArgs
         if attrs:
             dft,keys,argext = fn.func_dft
-            isAwgs = 1 if "awgs" in argext[:2]  else 0
-            if isAwgs and signature: #py3.3+
-                isAwgs = '**' in str(signature(fn))
+            isAwgs = argext[1]
                 
         args = []
         keysL = []
@@ -219,7 +219,12 @@ class valid:
                     val = awgs.pop(param)
                     args.append(val)  
             else: 
-                val = d.get(param, '') #val = rq.form.get(param, '')
+                #val = d.get(param, '') #val = rq.form.get(param, '')
+                if param in d:
+                    val = d[param]
+                else:
+                    val = unVal()
+                
                 if param=='token' and val in ("", None, "null", "undefined"):
                     val = rq.META.get('HTTP_X_TOKEN') or rq.COOKIES.get(param, '')
                 if param == 'request' and val=="":
